@@ -1,9 +1,11 @@
 """Asynchronous Python client for the Rivian API."""
+
 from __future__ import annotations
 
 import asyncio
 import logging
 import socket
+import sys
 import time
 import uuid
 from collections.abc import Callable
@@ -11,7 +13,6 @@ from typing import Any, Type
 from warnings import warn
 
 import aiohttp
-import async_timeout
 from aiohttp import ClientResponse, ClientWebSocketResponse
 
 from .const import LIVE_SESSION_PROPERTIES, VEHICLE_STATE_PROPERTIES, VehicleCommand
@@ -29,6 +30,11 @@ from .exceptions import (
 from .utils import generate_vehicle_command_hmac
 from .ws_monitor import WebSocketMonitor
 
+if sys.version_info >= (3, 11):
+    import asyncio as async_timeout
+else:
+    import async_timeout
+
 _LOGGER = logging.getLogger(__name__)
 
 GRAPHQL_BASEPATH = "https://rivian.com/api/gql"
@@ -248,10 +254,12 @@ class Rivian:
         device_name: str,
         public_key: str,
     ) -> bool:
-        """Enable control of a vehicle by enrolling a phone.
+        """Enroll a phone.
 
         To generate a public/private key for enrollment, use the `utils.generate_key_pair` function.
         The private key will need to be retained to sign commands sent via the `send_vehicle_command` method.
+        To enable vehicle control, the phone will then also need to be paired locally via BLE,
+        which can be done via `ble.pair_phone`.
         """
         url = GRAPHQL_GATEWAY
         headers = BASE_HEADERS | {
@@ -377,7 +385,7 @@ class Rivian:
             "U-Sess": self._user_session_token,
         }
 
-        graphql_query = "query getVehicleImages( $extension: String $resolution: String $versionForVehicle: String $versionForPreOrder: String ) { getVehicleOrderMobileImages( resolution: $resolution extension: $extension version: $versionForPreOrder ) { ...image } getVehicleMobileImages( resolution: $resolution extension: $extension version: $versionForVehicle ) { ...image } } fragment image on VehicleMobileImage { orderId vehicleId url extension resolution size design placement }"
+        graphql_query = "query getVehicleImages( $extension: String $resolution: String $versionForVehicle: String $versionForPreOrder: String ) { getVehicleOrderMobileImages( resolution: $resolution extension: $extension version: $versionForPreOrder ) { ...image } getVehicleMobileImages( resolution: $resolution extension: $extension version: $versionForVehicle ) { ...image } } fragment image on VehicleMobileImage { orderId vehicleId url extension resolution size design placement overlays { url overlay zIndex } }"
 
         graphql_json = {
             "operationName": "getVehicleImages",
